<?php

namespace WilokeFilterCards\Shared;

class HtmlHelper
{
	public static function getBg($aItem)
	{
		if (empty($aItem['background_image'])) {
			return '';
		}

		$url = "";
		if (isset($aItem['background_image']['id'])) {
			$url = wp_get_attachment_image_url($aItem['background_image']['id'], 'large');
		}

		if (empty($url)) {
			$url = $aItem['background_image']['url'];
		}
		return $url;
	}

	public static function getIcon($aItem)
	{
		if (isset($aItem['icon'])) {
			return $aItem['icon'];
		}
		return '';
	}

	public static function getTitle($aItem)
	{
		if (isset($aItem['title'])) {
			return $aItem['title'];
		}
		return '';
	}

	public static function getDesc($aItem)
	{
		if (isset($aItem['description'])) {
			return $aItem['description'];
		}
		return '';
	}

	public static function getSupTitle($aItem)
	{
		if (isset($aItem['sup_title'])) {
			return $aItem['sup_title'];
		}
		return '';
	}

	public static function getLink($aItem)
	{
		if (!isset($aItem['link'])) {
			return '#';
		}

		return $aItem['link']['url'];
	}

	public static function getLinkTarget($aItem): string
	{
		if (!isset($aItem['link'])) {
			return '_self';
		}

		return $aItem['link']['is_external'] ? '_blank' : '_self';
	}

	public static function isNofollow($aItem): bool
	{
		if (!isset($aItem['link'])) {
			return false;
		}

		return $aItem['link']['nofollow'];
	}

	public static function getHtmlTag($aItem): string
	{
		if (empty($aItem['title_html_tag'])) {
			return 'h3';
		}

		return $aItem['title_html_tag'];
	}

	public static function renderItem(array $aItem, $extraClasses = '')
	{
		$title = self::getTitle($aItem);
		$supTitle = self::getSupTitle($aItem);
		$link = self::getLink($aItem);
		$target = self::getLinkTarget($aItem);
		$isNoFollow = self::isNofollow($aItem);
		$htmlTag = self::getHtmlTag($aItem);
		$bgImage = self::getBg($aItem);

		$classes = 'wiloke-filter-card-item';
		if (!empty($extraClasses)) {
			$classes .= ' ' . $extraClasses;
		}

		?>
        <a class="<?php echo esc_attr($classes); ?>"
           rel="<?php echo esc_attr($isNoFollow ? 'nofollow' : 'dofollow'); ?>"
           target="<?php echo esc_attr($target); ?>"
           href="<?php echo esc_url($link); ?>">
            <div class="wil-filter-card__background" style="background-image: url(<?php echo esc_url($bgImage); ?>)"></div>
            <div class="wil-filter-card__content">
				<?php if (!empty($supTitle)) : ?>
                    <p class="wil-filter-card__category"><?php echo esc_html($supTitle); ?></p>
				<?php endif; ?>
                <<?php echo esc_attr($htmlTag); ?> class="wil-filter-card__heading"><?php echo esc_html($title); ?></<?php echo esc_attr($htmlTag); ?>>
            </div>
        </a>
		<?php
	}
}
