<?php

namespace WilokeFilterCards\Widgets;

use Elementor\Controls_Manager;
use Elementor\Widget_Base;
use WilokeFilterCards\Shared\HtmlHelper;

class FilterCardPostsWidget extends Widget_Base
{

	public function get_style_depends()
	{
		return [WILOKE_FILTER_CARDS_ID];
	}

	public function get_name()
	{
		return WILOKE_FILTER_CARDS_ID . '-post';
	}

	public function get_title()
	{
		return 'Wiloke Filter Cards (Posts)';
	}

	public function get_icon()
	{
		return 'fa-regular fa-sensor';
	}

	public function get_categories()
	{
		return ['wiloke-category'];
	}

	private function generatePostTypeOptions(): array
	{
		$aPostTypes = get_post_types(['public' => true, 'exclude_from_search' => false], 'objects');
		$aOptions = [];
		foreach ($aPostTypes as $postType) {
			$aOptions[$postType->name] = $postType->label;
		}

		return $aOptions;
	}


	protected function _register_controls()
	{
		$this->start_controls_section(
			'content_section',
			[
				'label' => esc_html__('Card Items', 'wiloke-filter-cards'),
				'tab'   => Controls_Manager::TAB_CONTENT,
			]
		);

		$this->add_control(
			'post_type',
			[
				'label'   => esc_html__('Post Type', 'wiloke-filter-cards'),
				'type'    => Controls_Manager::SELECT,
				'default' => 'post',
				'options' => $this->generatePostTypeOptions()
			]
		);


		$this->add_control(
			'post_ids',
			[
				'label'       => esc_html__('Specified post ids', 'wiloke-filter-cards'),
				'description' => esc_html__('Enter post ids separated by comma. Example: 1,2,3,4',
					'wiloke-filter-cards'),
				'type'        => Controls_Manager::TEXT,
				'default'     => ''
			]
		);

		$this->add_control(
			'posts_per_page',
			[
				'label'   => esc_html__('Number of Items', 'wiloke-filter-cards'),
				'type'    => Controls_Manager::NUMBER,
				'default' => 4
			]
		);

		$this->add_control(
			'orderby',
			[
				'label'       => esc_html__('Order By', 'wiloke-filter-cards'),
				'description' => esc_html__('If the specified post ids are not empty, the posts are displayed exactly what you specified.',
					'wiloke-filter-cards'),
				'type'        => Controls_Manager::SELECT,
				'default'     => 'date',
				'options'     => [
					'date'          => esc_html__('Post Date', 'wiloke-expanding-flex-cards'),
					'title'         => esc_html__('Post Title', 'wiloke-expanding-flex-cards'),
					'comment_count' => esc_html__('Comment count', 'wiloke-expanding-flex-cards'),
					'menu_order'    => esc_html__('Page order', 'wiloke-expanding-flex-cards'),
				],
			]
		);

		$this->add_control(
			'order',
			[
				'label'   => esc_html__('Order', 'wiloke-filter-cards'),
				'type'    => Controls_Manager::SELECT,
				'default' => 'desc',
				'options' => [
					'desc' => esc_html__('DESC', 'wiloke-filter-cards'),
					'asc'  => esc_html__('ASC', 'wiloke-filter-cards'),
				]
			]
		);

		$this->add_control(
			'link_target',
			[
				'label'   => esc_html__('Link Target', 'wiloke-expanding-flex-cards'),
				'type'    => Controls_Manager::SELECT,
				'default' => '_self',
				'options' => [
					'_self'  => esc_html__('Same Window', 'wiloke-expanding-flex-cards'),
					'_blank' => esc_html__('New Window', 'wiloke-expanding-flex-cards'),
				],
			]
		);

		$this->add_control(
			'title_html_tag',
			[
				'label'   => esc_html__('Title HTML Tag', 'wiloke-expanding-flex-cards'),
				'type'    => Controls_Manager::SELECT,
				'default' => 'h3',
				'options' => [
					'h1' => 'H1',
					'h2' => 'H2',
					'h3' => 'H3',
					'h4' => 'H4',
					'h5' => 'H5',
					'h6' => 'H6',
					'p'  => 'p'
				],
			]
		);


		$this->end_controls_section();
	}

	protected function render()
	{
		$settings = $this->get_settings_for_display();

		$aArgs = [
			'post_type'      => $settings['post_type'],
			'posts_per_page' => $settings['posts_per_page'],
			'post_status'    => 'publish',
			'orderby'        => $settings['orderby'],
			'order'          => $settings['order'],
		];

		if (!empty($settings['post_ids'])) {
			$aArgs['post__in'] = explode(',', $settings['post_ids']);
			$aArgs['posts_per_page'] = count($aArgs['post__in']);
			$aArgs['orderby'] = 'post__in';
		}

		$aPosts = get_posts($aArgs);

		if (empty($aPosts) || is_wp_error($aPosts)) {
			return;
		}


		?>
        <div class="wiloke-filter-card-hero-section">
            <div class="wiloke-filter-card-grid">
				<?php
				foreach ($aPosts as $oPost) {
					$aItem = [];
					$aItem["title_html_tag"] = $settings["title_html_tag"];
					$aItem["title"] = $oPost->post_title;
					$aItem["link"] = [
						"url"         => get_permalink($oPost->ID),
						"nofollow"    => false,
						"is_external" => $settings["link_target"] == "_blank"
					];

					$aItem['background_image'] = [
						'id' => get_post_thumbnail_id($oPost)
					];


					HtmlHelper::renderItem($aItem);
				}
				?>
            </div>
        </div>
		<?php
	}
}
