<?php

namespace WilokeFilterCards\Widgets;

use Elementor\Controls_Manager;
use Elementor\Widget_Base;
use WilokeFilterCards\Shared\HtmlHelper;

class FilterCardTaxonomiesWidget extends Widget_Base
{

	public function get_style_depends()
	{
		return [WILOKE_FILTER_CARDS_ID];
	}

	public function get_name()
	{
		return WILOKE_FILTER_CARDS_ID . '-taxonomy';
	}

	public function get_title()
	{
		return 'Wiloke Filter Cards (Categories)';
	}

	public function get_icon()
	{
		return 'fa-regular fa-sensor';
	}

	public function get_categories()
	{
		return ['wiloke-category'];
	}

	private function generateTaxOptions(): array
	{
		$aTaxonomies = get_taxonomies(
			[
				'public' => true
			],
			'object'
		);

		$aOptions = [];
		foreach ($aTaxonomies as $taxonomy => $oTaxonomy) {
			$aOptions[$taxonomy] = $oTaxonomy->labels->name;
		}

		return $aOptions;
	}


	protected function _register_controls()
	{
		$this->start_controls_section(
			'content_section',
			[
				'label' => esc_html__('Card Items', 'wiloke-filter-cards'),
				'tab'   => Controls_Manager::TAB_CONTENT,
			]
		);

		$this->add_control(
			'taxonomy',
			[
				'label'   => esc_html__('Category Type', 'wiloke-filter-cards'),
				'type'    => Controls_Manager::SELECT,
				'default' => 'category',
				'options' => $this->generateTaxOptions()
			]
		);


		$this->add_control(
			'term_ids',
			[
				'label'       => esc_html__('Specified term ids', 'wiloke-filter-cards'),
				'description' => esc_html__('Enter term ids separated by comma. Example: 1,2,3,4',
					'wiloke-filter-cards'),
				'type'        => Controls_Manager::TEXT,
				'default'     => ''
			]
		);

		$this->add_control(
			'number_of_items',
			[
				'label'   => esc_html__('Number of Items', 'wiloke-filter-cards'),
				'type'    => Controls_Manager::NUMBER,
				'default' => 4
			]
		);

		$this->add_control(
			'hide_empty',
			[
				'label'       => esc_html__('Hide Empty Category', 'wiloke-expanding-flex-cards'),
				'description' => esc_html__('If there is no post belongs to a category, it will be ignored',
					'wiloke-filter-cards'),
				'type'        => Controls_Manager::SELECT,
				'default'     => 'yes',
				'options'     => [
					'yes' => esc_html__('Yes', 'wiloke-expanding-flex-cards'),
					'no'  => esc_html__('No', 'wiloke-expanding-flex-cards'),
				],
			]
		);

		$this->add_control(
			'orderby',
			[
				'label'       => esc_html__('Order By', 'wiloke-filter-cards'),
				'description' => esc_html__('If the specified post ids are not empty, the posts are displayed exactly what you specified.',
					'wiloke-filter-cards'),
				'type'        => Controls_Manager::SELECT,
				'default'     => 'count',
				'options'     => [
					'name'    => esc_html__('Name', 'wiloke-filter-cards'),
					'term_id' => esc_html__('Created Date', 'wiloke-filter-cards'),
					'count'   => esc_html__('Count', 'wiloke-filter-cards'),
				]
			]
		);

		$this->add_control(
			'order',
			[
				'label'   => esc_html__('Order', 'wiloke-filter-cards'),
				'type'    => Controls_Manager::SELECT,
				'default' => 'desc',
				'options' => [
					'desc' => esc_html__('DESC', 'wiloke-filter-cards'),
					'asc'  => esc_html__('ASC', 'wiloke-filter-cards'),
				]
			]
		);

		$this->add_control(
			'link_target',
			[
				'label'   => esc_html__('Link Target', 'wiloke-expanding-flex-cards'),
				'type'    => Controls_Manager::SELECT,
				'default' => '_self',
				'options' => [
					'_self'  => esc_html__('Same Window', 'wiloke-expanding-flex-cards'),
					'_blank' => esc_html__('New Window', 'wiloke-expanding-flex-cards'),
				],
			]
		);

		$this->add_control(
			'title_html_tag',
			[
				'label'   => esc_html__('Title HTML Tag', 'wiloke-expanding-flex-cards'),
				'type'    => Controls_Manager::SELECT,
				'default' => 'h3',
				'options' => [
					'h1' => 'H1',
					'h2' => 'H2',
					'h3' => 'H3',
					'h4' => 'H4',
					'h5' => 'H5',
					'h6' => 'H6',
					'p'  => 'p'
				],
			]
		);

		$this->add_control(
			'show_term_count',
			[
				'label'   => esc_html__('Show Post Count', 'wiloke-expanding-flex-cards'),
				'type'    => Controls_Manager::SELECT,
				'default' => 'yes',
				'options' => [
					'yes' => esc_html__('Yes', 'wiloke-expanding-flex-cards'),
					'no'  => esc_html__('No', 'wiloke-expanding-flex-cards'),
				],
			]
		);


		$this->end_controls_section();
	}

	protected function render()
	{
		$settings = $this->get_settings_for_display();

		if (empty($settings) || empty($settings["taxonomy"])) {
			return;
		}

		$aArgs = [
			'taxonomy'   => $settings["taxonomy"],
			'hide_empty' => $settings["hide_empty"] == "yes",
			'orderby'    => $settings["orderby"],
			'order'      => $settings['order'],
			'number'     => $settings['number_of_items']
		];

		if (!empty($settings['term_ids'])) {
			$aArgs['include'] = explode(',', $settings['term_ids']);
			$aArgs['orderby'] = 'include';
			$aArgs['number'] = count($aArgs['include']);
		}

		$aTerms = get_terms($aArgs);

		if (empty($aTerms) || is_wp_error($aTerms)) {
			return;
		}


		?>
        <div class="wiloke-filter-card-hero-section">
            <div class="wiloke-filter-card-grid">
				<?php
				foreach ($aTerms as $oTerm) {
					$aItem = [];
					$aItem["title_html_tag"] = $settings["title_html_tag"];
					$aItem["title"] = $oTerm->name;
					$aItem["link"] = [
						"url"         => get_term_link($oTerm),
						"nofollow"    => false,
						"is_external" => $settings["link_target"] == "_blank"
					];

					if (function_exists("get_field")) {
						$aFeaturedImage = get_field('featured_image', $oTerm);
						if (!empty($aFeaturedImage)) {
							$aItem["background_image"] = get_field('featured_image', $oTerm);
						}
					}

					if ($settings["show_term_count"] == "yes") {
						$aItem["sup_title"] = esc_html(sprintf(
							_n('%s Post', '%s Posts', $oTerm->count, 'wiloke-expanding-flex-cards'),
							$oTerm->count
						));
					}

					HtmlHelper::renderItem($aItem);
				}
				?>
            </div>
        </div>
		<?php
	}
}
