<?php

namespace WilokeFilterCards\Widgets;

use Elementor\Controls_Manager;
use Elementor\Repeater;
use Elementor\Widget_Base;
use WilokeFilterCards\Shared\HtmlHelper;


class FilterCardsManuallyWidget extends Widget_Base
{
	public function get_script_depends()
	{
		return [WILOKE_FILTER_CARDS_ID];
	}


	public function get_style_depends()
	{
		return [WILOKE_FILTER_CARDS_ID];
	}

	public function get_name()
	{
		return WILOKE_FILTER_CARDS_ID . '-manually';
	}

	public function get_title()
	{
		return 'Wiloke Filter Cards (Manually)';
	}

	public function get_icon()
	{
		return 'fa-regular fa-sensor';
	}

	public function get_categories()
	{
		return ['wiloke-category'];
	}

	protected function _register_controls()
	{
		$this->start_controls_section(
			'content_section',
			[
				'label' => esc_html__('Card Items', 'wiloke-filter-cards'),
				'tab'   => Controls_Manager::TAB_CONTENT,
			]
		);

		// Repeater control for Title and Description fields
		$repeater = new Repeater();
		$repeater->add_control(
			'sup_title',
			[
				'label'       => esc_html__('Sup Title', 'wiloke-filter-cards'),
				'type'        => Controls_Manager::TEXT,
				'default'     => esc_html__('Sup Title', 'wiloke-filter-cards'),
				'label_block' => true,
			]
		);

		$repeater->add_control(
			'title',
			[
				'label'       => esc_html__('Title', 'wiloke-filter-cards'),
				'type'        => Controls_Manager::TEXT,
				'default'     => esc_html__('Title', 'wiloke-filter-cards'),
				'label_block' => true,
			]
		);

		$repeater->add_control(
			'background_image',
			[
				'label'   => esc_html__('Background Image', 'wiloke-filter-cards'),
				'type'    => Controls_Manager::MEDIA,
				'default' => [
					'url' => '',
				],
			]
		);

		$repeater->add_control(
			'link',
			[
				'label'         => esc_html__('Link', 'wiloke-filter-cards'),
				'type'          => Controls_Manager::URL,
				'placeholder'   => esc_html__('https://your-link.com', 'wiloke-filter-cards'),
				'show_external' => true,
				'default'       => [
					'url'         => '',
					'is_external' => true,
					'nofollow'    => true,
				],
			]
		);

		$repeater->add_control(
			'link_target',
			[
				'label'   => esc_html__('Link Target', 'wiloke-filter-cards'),
				'type'    => Controls_Manager::SELECT,
				'default' => '_self',
				'options' => [
					'_self'  => esc_html__('Same Window', 'wiloke-filter-cards'),
					'_blank' => esc_html__('New Window', 'wiloke-filter-cards'),
				],
			]
		);

		// Repeatable control for Title and Description fields
		$this->add_control(
			'items',
			[
				'label'  => esc_html__('Card Item', 'wiloke-filter-cards'),
				'type'   => Controls_Manager::REPEATER,
				'fields' => $repeater->get_controls()
			]
		);

		$this->add_control(
			'title_html_tag',
			[
				'label'   => esc_html__('Title HTML Tag', 'wiloke-filter-cards'),
				'type'    => Controls_Manager::SELECT,
				'default' => 'h3',
				'options' => [
					'h1' => 'H1',
					'h2' => 'H2',
					'h3' => 'H3',
					'h4' => 'H4',
					'h5' => 'H5',
					'h6' => 'H6',
					'p'  => 'p'
				],
			]
		);


		$this->end_controls_section();
	}

	protected function render()
	{
		$settings = $this->get_settings_for_display();

		if (empty($settings) || empty($settings["items"])) {
			return;
		}

		?>
        <div class="wiloke-filter-card-hero-section">
            <div class="wiloke-filter-card-grid">
				<?php
				foreach ($settings["items"] as $aItem) {
					$aItem["title_html_tag"] = $settings["title_html_tag"];
					HtmlHelper::renderItem($aItem);
				}
				?>
            </div>
        </div>
		<?php
	}
}
